#ifndef S9X_CPU_H
#define S9X_CPU_H

#include "defines.h"
#include "frend.h"
#include "misc.h"
#include "skins.h"

class s9x_CPU :		public s9x_Notepage
{
 private:
   fr_Checkbox		HDMA;
   fr_Checkbox		SpeedHacks;
   fr_Checkbox		SuperFX;
   fr_Checkbox		DSP1;
   fr_Slider		Cycles;
   void			EventOccurred(fr_Event*e);
 public:
 			s9x_CPU(fr_Notebook*parent);
  void			Set9xVersion(float version);
};                                                                          

#endif
